For AI agents: an LLM-friendly Markdown version of every page is available by appending .md to its URL or by sending an Accept: text/markdown request header. The full documentation index is at https://www.ankr.com/docs/llms.txt
Skip to main content

TON — Methods (3/3)

API reference for TON. All methods ->

Part 3 of 3: 1 · 2 · 3

getTransactions​

Retrieves transactions.

Retrieves transaction history of a given address.

Parameters​


  • address (string; query; required): an identifier of a target TON account.
  • limit (integer; query; default=10, max=100): maximum number of transactions in response.
  • lt (integer; query): logical time of transaction to start with, must be sent with hash.
  • hash (string; query): the hash of transaction to start with, in base64 or hex encoding , must be sent with lt.
  • to_lt (integer; query): logical time of transaction to finish with (to get tx from lt to to_lt).
  • archival (boolean; query; default=false): by default getTransaction request is processed by any available liteserver. If archival=true only liteservers with full history are used.

Returns​

The transaction history for a specific address.

Request example​

curl -X GET https://rpc.ankr.com/premium-http/ton_api_v2/YOUR_ANKR_API_KEY/getTransactions?address=EQD5dunJah1URq6Hffu7SEpCSOd5PnuzxiqgoRHvkSN-q19W

Response example​

{
"ok": true,
"result": [
{
"@type": "raw.transaction",
"utime": 1730897178,
"data": "te6cckECDwEAAywAA7V/l26clqHVRGrod9+7tISkJI53k+e7PGKqChEe+RI36rAAAuDEt9e0EUhqqRoLlokU16oee06iuNKCfrXMhyS9QXJLNJK+RvjwAALf81h8KBZytlGgADRhjwMIAQIDAgHgBAUAgnKmm1F2uF+qjoLb+DOkjIiO+1S2/rUFfz/9X0ecgCrNJJxt7rYpNtcbz4bUhkV3+hJYM6a4v6txgynCn27hbW/LAhkEhZUJANqpBRhgw1ARDQ4BsWgAAHEQFvmJp3gRyAJ1sBIV0YcBim66VsLr6L2rS6H3pL8APl26clqHVRGrod9+7tISkJI53k+e7PGKqChEe+RI36rQDaqQUAYQFLQAAFwYloDkhM5Wyh7ABgEB3wcBqA+KfqVUbeTv2XoE7jY5HJgB8zYowBXIml4lYvHRjdV68RJV0Fi8i20THzvW/WQH84kAAA4iAt8xNO8COQBOtgJCujDgMU3XSthdfRe1aXQ+9JfCAwwCsWgB8u3TktQ6qI1dDvv3dpCUhJHO8nz3Z4xVQUIj3yJG/VcAIzum7Z4PaYlBTeFvKo6mdRJVSxaBZjYWdNcZV1Ty5TgQDUbO0AYZHTgAAFwYlvr2hM5WyjXgCAkCATQKCwGnF41FGVRt5O/ZegTuNjkcmAAAcRAW+YmneBHIAnWwEhXRhwGKbrpWwuvovatLofekvwAADiIC3zE07wI5AE62AkK6MOAxTddK2F19F7VpdD70l8QHDAhCAo9FLXpN/XQGa2gjZRdyWe0Fc0Q1vna1/UvV2K8rfD1oAIcAgB8zYowBXIml4lYvHRjdV68RJV0Fi8i20THzvW/WQH84kALETqZS1AkoWcZ9pE5Mo63WVlsOKJfWQKLFG/s3DYh3+gAaAAAAADEwOTUxNTg2OACeQH0MCL8UAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABvyYlq8EwZHRAAAAAAAAIAAAAAAALC24AfOr7B+9wHRF8yKXY1QVDD2tgXWyS0aakzhF8WbEGQR6TI4r5Y",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "50630341000001",
"hash": "/PZphaovGJ1xCTklvEPzGszPvBaotdzWcon79et+Nvw="
},
"fee": "1640116",
"storage_fee": "5716",
"other_fee": "1634400",
"in_msg": {
"@type": "raw.message",
"source": "EQAAOIgLfMTTvAjkATrYCQrow4DFN10rYXX0XtWl0PvSX5uk",
"destination": "EQD5dunJah1URq6Hffu7SEpCSOd5PnuzxiqgoRHvkSN-q19W",
"value": "57320468",
"fwd_fee": "526938",
"ihr_fee": "0",
"created_lt": "50630337000002",
"body_hash": "vt02QoQHP7hw48TBJm8i1YII+Zx8kL/QfNVj79Kmt7w=",
"msg_data": {
"@type": "msg.dataRaw",
"body": "te6cckEBAgEAZgABqA+KfqVUbeTv2XoE7jY5HJgB8zYowBXIml4lYvHRjdV68RJV0Fi8i20THzvW/WQH84kAAA4iAt8xNO8COQBOtgJCujDgMU3XSthdfRe1aXQ+9JfCAwEAGgAAAAAxMDk1MTU4NjicCb0U",
"init_state": ""
},
"message": "D4p+pVRt5O/ZegTuNjkcmAHzNijAFciaXiVi8dGN1XrxElXQWLyLbRMfO9b9ZAfziQAADiIC3zE0\n7wI5AE62AkK6MOAxTddK2F19F7VpdD70l8ID\n"
},
"out_msgs": [
{
"@type": "raw.message",
"source": "EQD5dunJah1URq6Hffu7SEpCSOd5PnuzxiqgoRHvkSN-q19W",
"destination": "EQCM7pu2eD2mJQU3hbyqOpnUSVUsWgWY2FnTXGVdU8uU4Ddb",
"value": "55686068",
"fwd_fee": "822940",
"ihr_fee": "0",
"created_lt": "50630341000002",
"body_hash": "Ycyf2S915TpjkcLaOH70Kse87Z1rZrF65nPLm/70Rms=",
"msg_data": {
"@type": "msg.dataRaw",
"body": "te6cckEBAgEAZgABpxeNRRlUbeTv2XoE7jY5HJgAAHEQFvmJp3gRyAJ1sBIV0YcBim66VsLr6L2rS6H3pL8AAA4iAt8xNO8COQBOtgJCujDgMU3XSthdfRe1aXQ+9JfEBwEAGgAAAAAxMDk1MTU4NjhoTgE0",
"init_state": "te6cckEBAwEAbgACATQBAghCAo9FLXpN/XQGa2gjZRdyWe0Fc0Q1vna1/UvV2K8rfD1oAIcAgB8zYowBXIml4lYvHRjdV68RJV0Fi8i20THzvW/WQH84kALETqZS1AkoWcZ9pE5Mo63WVlsOKJfWQKLFG/s3DYh3+vXib6g="
},
"message": "F41FGVRt5O/ZegTuNjkcmAAAcRAW+YmneBHIAnWwEhXRhwGKbrpWwuvovatLofekvwAADiIC3zE0\n7wI5AE62AkK6MOAxTddK2F19F7VpdD70l8QG\n"
}
]
}
]
}

getBlockTransactions​

Retrieves transactions of a given block.

Parameters​


  • workchain (integer; query; required): the block workchain ID. Example: -1 for the masterchain.
  • shard (integer; query; required): the block shard ID. Example: -9223372036854775808 for the masterchain.
  • seqno (integer; query; required): the sequence number of the block. Example: 39064985.
  • root_hash (string; query): the root hash of the block for which to request transactions.
  • file_hash (string; query): the file hash associated with the block.
  • after_lt (integer; query): the logical time (LT) marker after which to retrieve transactions.
  • after_hash (string; query): the hash of the last transaction from which to continue fetching additional transactions.
  • count (integer; query; default=40): max number of transactions to return.

Returns​

Transactions from a specific block on the TON blockchain.

Request example​

curl -X GET https://rpc.ankr.com/premium-http/ton_api_v2/YOUR_ANKR_API_KEY/getBlockTransactions?workchain=-1&shard=-9223372036854775808&seqno=39064985

Response example​

{
"ok": true,
"result": {
"@type": "blocks.transactions",
"id": {
"@type": "ton.blockIdExt",
"workchain": -1,
"shard": "-9223372036854775808",
"seqno": 39064985,
"root_hash": "8txd0JPm3PHUMknZMybwYD8WlGT+nqOQjJ3pqmd22/s=",
"file_hash": "jVToDU7mOXsUoHRntkmE6/hbA1AgrFMMeFcqlnwv75M="
},
"req_count": 40,
"incomplete": false,
"transactions": [
{
"@type": "blocks.shortTxId",
"mode": 135,
"account": "-1:3333333333333333333333333333333333333333333333333333333333333333",
"lt": "47805438000001",
"hash": "oWXZAgtiaqG69JC90PhKUCu/czgLghQVqQGAhxIetMY="
},
{
"@type": "blocks.shortTxId",
"mode": 135,
"account": "-1:3333333333333333333333333333333333333333333333333333333333333333",
"lt": "47805438000002",
"hash": "gG/fp7ukb3YHhcqRqhARG24xuNncdgc7dT4aSWLhRCI="
},
{
"@type": "blocks.shortTxId",
"mode": 135,
"account": "-1:5555555555555555555555555555555555555555555555555555555555555555",
"lt": "47805438000003",
"hash": "6p8ROuJ33hA6l7SrfhiXG1XB8YUNEnm05IElYQQCDek="
}
],
"@extra": "1731071592.980471:0:0.13996576074060574"
}
}

getBlockTransactionsExt​

Retrieves block transactions extended info.

Parameters​


  • workchain (integer; query; required): the block workchain ID. Example: -1 for the masterchain.
  • shard (integer; query; required): the block shard ID. Example: -9223372036854775808 for the masterchain.
  • seqno (integer; query; required): the sequence number of the block. Example: 39064985.
  • root_hash (string; query): the root hash of the block for which to request transactions.
  • file_hash (string; query): the file hash associated with the block.
  • after_lt (integer; query): the logical time (LT) marker after which to retrieve transactions.
  • after_hash (string; query): the hash of the last transaction from which to continue fetching additional transactions.
  • count (integer; query; default=40): max number of transactions to return.

Returns​

Detailed information about transactions from a specific block on the TON blockchain.

Request example​

curl -X GET https://rpc.ankr.com/premium-http/ton_api_v2/YOUR_ANKR_API_KEY/getBlockTransactionsExt?workchain=-1&shard=-9223372036854775808&seqno=39064985

Response example​

{
"ok": true,
"result": {
"@type": "blocks.transactionsExt",
"id": {
"@type": "ton.blockIdExt",
"workchain": -1,
"shard": "-9223372036854775808",
"seqno": 39064985,
"root_hash": "8txd0JPm3PHUMknZMybwYD8WlGT+nqOQjJ3pqmd22/s=",
"file_hash": "jVToDU7mOXsUoHRntkmE6/hbA1AgrFMMeFcqlnwv75M="
},
"req_count": 40,
"incomplete": false,
"transactions": [
{
"@type": "raw.transaction",
"address": {
"@type": "accountAddress",
"account_address": "Ef8zMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzM0vF"
},
"utime": 1721184636,
"data": "te6cckECBgEAASwAA69zMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzAAArepIme4GscsDwDDBgx9i/DeB5aFmy2vrV8aOK0rP/cq/8TPKZcwAAK3qSFzlCZpcxfAABQIAQIDAAEgAIJy8I5H0zoxilm4IYvCWq+YZvggOAzax3zPCIkpOOBNG8wO3imDKvL7ljWwH4GPI4A1OWEW8XeiXiwJjU86+K4vmQIFIDAkBAUAoEMBkBCwdgAAAAAAAAAAAIgAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFvAAAAAAAAAAAAAAAABLUUtpEnlC4z33SeGHxRhIq/htUa7i3D8ghbwxhQTn44ES774TA==",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "47805438000001",
"hash": "oWXZAgtiaqG69JC90PhKUCu/czgLghQVqQGAhxIetMY="
},
"fee": "0",
"storage_fee": "0",
"other_fee": "0",
"out_msgs": [],
"account": "-1:3333333333333333333333333333333333333333333333333333333333333333"
},
{
"@type": "raw.transaction",
"address": {
"@type": "accountAddress",
"account_address": "Ef8zMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzM0vF"
},
"utime": 1721184636,
"data": "te6cckECBwEAAYoAA69zMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzAAArepIme4KhZdkCC2Jqobr0kL3Q+EpQK79zOAuCFBWpAYCHEh60xgAAK3qSJnuBZpcxfAABQIAQIDAQGgBACCcg7eKYMq8vuWNbAfgY8jgDU5YRbxd6JeLAmNTzr4ri+ZpP0ft+83iz9Yc0BgMlvUwWg3jAnIjmISfn+TgvvOiOICDwQJLVTvQJgRBQYAq2n+AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAE/zMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzS1U70CAAAAFb1JEz3AM0uYvhAAKBCr3AQsHYAAAAAAAAAAABkAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABbwAAAAAAAAAAAAAAAAS1FLaRJ5QuM990nhh8UYSKv4bVGu4tw/IIW8MYUE5+OBOSEDw0=",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "47805438000002",
"hash": "gG/fp7ukb3YHhcqRqhARG24xuNncdgc7dT4aSWLhRCI="
},
"fee": "0",
"storage_fee": "0",
"other_fee": "0",
"in_msg": {
"@type": "raw.message",
"source": {
"@type": "accountAddress",
"account_address": "Ef8AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAADAU"
},
"destination": {
"@type": "accountAddress",
"account_address": "Ef8zMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzMzM0vF"
},
"value": "3042163970",
"fwd_fee": "0",
"ihr_fee": "0",
"created_lt": "47805438000000",
"body_hash": "lqKW0iTyhcZ77pPDD4owkVfw2qNdxbh+QQt4YwoJz8c=",
"msg_data": {
"@type": "msg.dataRaw",
"body": "te6cckEBAQEAAgAAAEysuc0=",
"init_state": ""
}
},
"out_msgs": [],
"account": "-1:3333333333333333333333333333333333333333333333333333333333333333"
},
{
"@type": "raw.transaction",
"address": {
"@type": "accountAddress",
"account_address": "Ef9VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVbxn"
},
"utime": 1721184636,
"data": "te6cckECBgEAASwAA691VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVAAArepIme4OECgCvSheQctVrVPqeBE/WfbkG6v5cpslm2if1ScBQRgAAK3qSFzlDZpcxfAABQIAQIDAAEgAIJyQ/ThOpAPm9H/T3ILcT7NCWm9UnbAgiq5qKeHYGOf36hhkadzn9gB0z9C3sKgAmTwI1mVw0NYAp/yY+U2+xU+aAIFMDAkBAUAoEGCkBCwdgAAAAAAAAAAAEIAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAFvAAAAAAAAAAAAAAAABLUUtpEnlC4z33SeGHxRhIq/htUa7i3D8ghbwxhQTn44ECXKhng==",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "47805438000003",
"hash": "6p8ROuJ33hA6l7SrfhiXG1XB8YUNEnm05IElYQQCDek="
},
"fee": "0",
"storage_fee": "0",
"other_fee": "0",
"out_msgs": [],
"account": "-1:5555555555555555555555555555555555555555555555555555555555555555"
}
],
"@extra": "1731071979.505911:1:0.010321268558367347"
}
}

tryLocateTx​

Locates outgoing transaction.

Locates an outgoing transaction of the destination address by incoming message.

Parameters​


  • source (string; query; required): the source address of the transaction.
  • destination (string; query; required): recipient address of the transaction.
  • created_lt (string; query; required): the logical time when the transaction was created.

Returns​

Specific transaction on the TON blockchain based on the source address, destination address, and the logical time of its creation.

Request example​

curl -X GET https://rpc.ankr.com/premium-http/ton_api_v2/YOUR_ANKR_API_KEY/tryLocateTx?source=UQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zTI1&destination=UQBP4mzpDIywL1SV-Wp9ZuBBlzprR9eXQgSYGEXiUEHm73vA&created_lt=47597573000002

Response example​

{
"ok": true,
"result": {
"@type": "raw.transaction",
"utime": 1720370807,
"data": "te6cckECCAEAAcYAA7N0/ibOkMjLAvVJX5an1m4EGXOmtH15dCBJgYReJQQebvAAArSixuS0NxLUvVgs8QeGGFM2MZwhibMZb5gyItVOLXOT/S0xskoAAAK0graeWDZorGdwABRUR+gBAgMBAaAEAIJyQ6mmQyZ39HLmBav8jckU7IrGamu4wzwWzKlJuYOGa/n6kZCfzjVebR8px97WNeOqId7XzjMSA2dM8e5vAZIEWgIVDIF/yMPQkBhTiBEGBwGvSAAvs7wFs7x4S8B9plt/S8M02irdNOUxttiffJcI1kFvmwAT+Js6QyMsC9UlflqfWbgQZc6a0fXl0IEmBhF4lBB5u8w9CQAGDGcIAABWlFjcloTNFYzuwAUAagAAAABidWdhdHRpYm95dmljZSAyNjUsMDAwIPCfko4gYXZhaWxhYmxlIG9uIGZyYWdtZW50AJonyCcQAAAAAAAAAAADAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABbwAAAAAAAAAAAAAAAAS1FLaRJ5QuM990nhh8UYSKv4bVGu4tw/IIW8MYUE5+OBHSfO+8=",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "47597573000003",
"hash": "mlVb0ixiGkELIAog5jwcqDOEcJa3R1CQk/20yaYAQ10="
},
"fee": "41535",
"storage_fee": "1535",
"other_fee": "40000",
"in_msg": {
"@type": "raw.message",
"source": "EQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zW_w",
"destination": "EQBP4mzpDIywL1SV-Wp9ZuBBlzprR9eXQgSYGEXiUEHm7yYF",
"value": "1000000",
"fwd_fee": "406404",
"ihr_fee": "0",
"created_lt": "47597573000002",
"body_hash": "0+UqzPwXQY+jCm7ohKTneJ+Yi3q08vctwy000JALqts=",
"msg_data": {
"@type": "msg.dataText",
"text": "YnVnYXR0aWJveXZpY2UgMjY1LDAwMCDwn5KOIGF2YWlsYWJsZSBvbiBmcmFnbWVudA=="
},
"message": "bugattiboyvice 265,000 💎 available on fragment"
},
"out_msgs": []
}
}

tryLocateResultTx​

Locates outgoing transaction.

Same as previous. Locates an outgoing transaction of destination address by incoming message.

Parameters​


  • source (string; query; required): the source address of the transaction.
  • destination (string; query; required): the recipient address of the transaction.
  • created_lt (string; query; required): the logical time when the transaction was created.

Returns​

Specific transaction on the TON blockchain based on the source address, destination address, and the logical time of its creation.

Request example​

curl -X GET https://rpc.ankr.com/premium-http/ton_api_v2/YOUR_ANKR_API_KEY/tryLocateResultTx?source=UQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zTI1&destination=UQBP4mzpDIywL1SV-Wp9ZuBBlzprR9eXQgSYGEXiUEHm73vA&created_lt=47597573000002

Response example​

{
"ok": true,
"result": {
"@type": "raw.transaction",
"utime": 1720370807,
"data": "te6cckECCAEAAcYAA7N0/ibOkMjLAvVJX5an1m4EGXOmtH15dCBJgYReJQQebvAAArSixuS0NxLUvVgs8QeGGFM2MZwhibMZb5gyItVOLXOT/S0xskoAAAK0graeWDZorGdwABRUR+gBAgMBAaAEAIJyQ6mmQyZ39HLmBav8jckU7IrGamu4wzwWzKlJuYOGa/n6kZCfzjVebR8px97WNeOqId7XzjMSA2dM8e5vAZIEWgIVDIF/yMPQkBhTiBEGBwGvSAAvs7wFs7x4S8B9plt/S8M02irdNOUxttiffJcI1kFvmwAT+Js6QyMsC9UlflqfWbgQZc6a0fXl0IEmBhF4lBB5u8w9CQAGDGcIAABWlFjcloTNFYzuwAUAagAAAABidWdhdHRpYm95dmljZSAyNjUsMDAwIPCfko4gYXZhaWxhYmxlIG9uIGZyYWdtZW50AJonyCcQAAAAAAAAAAADAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABbwAAAAAAAAAAAAAAAAS1FLaRJ5QuM990nhh8UYSKv4bVGu4tw/IIW8MYUE5+OBHSfO+8=",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "47597573000003",
"hash": "mlVb0ixiGkELIAog5jwcqDOEcJa3R1CQk/20yaYAQ10="
},
"fee": "41535",
"storage_fee": "1535",
"other_fee": "40000",
"in_msg": {
"@type": "raw.message",
"source": "EQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zW_w",
"destination": "EQBP4mzpDIywL1SV-Wp9ZuBBlzprR9eXQgSYGEXiUEHm7yYF",
"value": "1000000",
"fwd_fee": "406404",
"ihr_fee": "0",
"created_lt": "47597573000002",
"body_hash": "0+UqzPwXQY+jCm7ohKTneJ+Yi3q08vctwy000JALqts=",
"msg_data": {
"@type": "msg.dataText",
"text": "YnVnYXR0aWJveXZpY2UgMjY1LDAwMCDwn5KOIGF2YWlsYWJsZSBvbiBmcmFnbWVudA=="
},
"message": "bugattiboyvice 265,000 💎 available on fragment"
},
"out_msgs": []
}
}

tryLocateSourceTx​

Locates incoming transaction.

Locates incoming transaction of source address by outgoing message.

Parameters​


  • source (string; query; required): the source address of the transaction.
  • destination (string; query; required): the recipient address of the transaction.
  • created_lt (string; query; required): the logical time when the transaction was created.

Returns​

The source transaction in the TON blockchain based on the source address, destination address, and the logical time of a result transaction.

Request example​

curl -X GET https://rpc.ankr.com/premium-http/ton_api_v2/YOUR_ANKR_API_KEY/tryLocateSourceTx?source=UQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zTI1&destination=UQBP4mzpDIywL1SV-Wp9ZuBBlzprR9eXQgSYGEXiUEHm73vA&created_lt=47597573000002

Response example​

{
"ok": true,
"result": {
"@type": "raw.transaction",
"utime": 1720370807,
"data": "te6cckECCwEAArMAA7VxfZ3gLZ3jwl4D7TLb+l4ZptFW6acpjbbE++S4RrILfNAAArSixuS0ELoQyiDrvrN3Z0DPMD02uBod3iPli5PYjRN2/Ub+3FzAAAK0or5PcBZorGdwADRkYqjIAQIDAgHgBAUAgnKKPjpYcmgZLfsPoW9xmCLuTvF605qU692DTlFlYt85leU7kkdddoIfJzvx8qfF8HlSpJoGlSpo4eN5F697Wt9PAg8MQoYYoYYEQAkKAeGIAC+zvAWzvHhLwH2mW39LwzTaKt005TG22J98lwjWQW+aBp2t/wOepbcynWvjnMnSZ74h87QzObNk6oolE6HVQhB28rHHhfhPHOxPhrn435Q7Y0DIBKfINv5sP+zJYHem6CFNTRi7NFY88AAA0IAAHAYBAd8HANBCACfxNnSGRlgXqkr8tT6zcCDLnTWj68uhAkwMIvEoIPN3mHoSAAAAAAAAAAAAAAAAAAAAAAAAYnVnYXR0aWJveXZpY2UgMjY1LDAwMCDwn5KOIGF2YWlsYWJsZSBvbiBmcmFnbWVudAGvSAAvs7wFs7x4S8B9plt/S8M02irdNOUxttiffJcI1kFvmwAT+Js6QyMsC9UlflqfWbgQZc6a0fXl0IEmBhF4lBB5u8w9CQAGDGcIAABWlFjcloTNFYzuwAgAagAAAABidWdhdHRpYm95dmljZSAyNjUsMDAwIPCfko4gYXZhaWxhYmxlIG9uIGZyYWdtZW50AJ1BnYMTiAAAAAAAAAAAEQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAgAG/JhKagTAxm8AAAAAAAAgAAAAAAA9aib6Td8cdWhCpStTRgutI+DjjUUflMzLbRvaXnP5FgQJAjDIpjigg=",
"transaction_id": {
"@type": "internal.transactionId",
"lt": "47597573000001",
"hash": "9BFX+3WF/g7lt+fmHWmyFraflfOoAG3s7z32tOx3HbQ="
},
"fee": "2705610",
"storage_fee": "10",
"other_fee": "2705600",
"in_msg": {
"@type": "raw.message",
"source": "",
"destination": "EQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zW_w",
"value": "0",
"fwd_fee": "0",
"ihr_fee": "0",
"created_lt": "0",
"body_hash": "ZSRHhXgmUkSeNbEYIOHUYXcW8kCvcG99IPJk4PWP6Lc=",
"msg_data": {
"@type": "msg.dataRaw",
"body": "te6cckEBAgEAuwABnNO1v+Bz1LbmU618c5k6TPfEPnaGZzZsnVFEonQ6qEIO3lY48L8J452J8Nc/G/KHbGgZAJT5Bt/Nh/2ZLA703QQpqaMXZorHngAAGhAAAwEA0EIAJ/E2dIZGWBeqSvy1PrNwIMudNaPry6ECTAwi8Sgg83eYehIAAAAAAAAAAAAAAAAAAAAAAABidWdhdHRpYm95dmljZSAyNjUsMDAwIPCfko4gYXZhaWxhYmxlIG9uIGZyYWdtZW506B10iw==",
"init_state": ""
},
"message": "07W/4HPUtuZTrXxzmTpM98Q+doZnNmydUUSidDqoQg7eVjjwvwnjnYnw1z8b8odsaBkAlPkG382H\n/ZksDvTdBCmpoxdmiseeAAAaEAAD\n"
},
"out_msgs": [
{
"@type": "raw.message",
"source": "EQAX2d4C2d48JeA-0y2_peGabRVumnKY22xPvkuEayC3zW_w",
"destination": "EQBP4mzpDIywL1SV-Wp9ZuBBlzprR9eXQgSYGEXiUEHm7yYF",
"value": "1000000",
"fwd_fee": "406404",
"ihr_fee": "0",
"created_lt": "47597573000002",
"body_hash": "0+UqzPwXQY+jCm7ohKTneJ+Yi3q08vctwy000JALqts=",
"msg_data": {
"@type": "msg.dataText",
"text": "YnVnYXR0aWJveXZpY2UgMjY1LDAwMCDwn5KOIGF2YWlsYWJsZSBvbiBmcmFnbWVudA=="
},
"message": "bugattiboyvice 265,000 💎 available on fragment"
}
]
}
}